Name:           gnofract4d
Version:        4.3
Release:        %mkrel 9
Group:          Graphics/Utilities
License:        BSD
Summary:        A fractal generation program for linux
URL:            https://fract4d.github.io/gnofract4d/
Source0:        https://github.com/fract4d/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.gz
Patch0:         gnofract4d-4.3-fix_desktop_file.patch
Patch1:         gnofract4d-4.3-linking.patch
Patch2:         gnofract4d-c99.patch
Patch3:		gnofract4d-build-flags.patch
# Upstream patches:
Patch101:       0001-fract4dc-sanitize-#154.patch
Patch102:       0002-Hold-the-GIL-while-deleting-python-objects.patch
Patch103:       0003-fix-#177_avoid-GIL-deadlock.patch
# Avoid PyEval_InitThreads, which does nothing in python 3.9-3.12 and has been
# remove entirely in python 3.13
Patch104:       gnofract4d-pyeval-initthreads.patch
BuildRequires:  pyproject-rpm-macros
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng)
#needed at runtime, see bug 9091
Requires:       gcc

%description
Gnofract 4D is a free, open source program which allows anyone to
create beautiful images called fractals. The images are automatically
created by the computer based on mathematical principles.
These include the Mandelbrot and Julia sets and many more.
You don't need to do any math: you can explore a universe of images
just using a mouse.

%prep
%autosetup -p1

%generate_buildrequires
export CFLAGS=""
%pyproject_buildrequires

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files fract4d fract4d_compiler fract4dgui

# duplicate docs
rm -rf %{buildroot}%{_docdir}/%{name}

# fix rights
chmod 644 %{buildroot}%{_datadir}/%{name}/maps/royal.map

# install manapage
mkdir -p %{buildroot}%{_mandir}/man1/
install -m 0644 doc/gnofract4d.1 %{buildroot}%{_mandir}/man1/

%files -f %{pyproject_files}
%doc README.md
%license LICENSE
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/pixmaps/%{name}*
%{_datadir}/mime/packages/%{name}-mime.xml
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_mandir}/man1/%{name}.1*


%changelog
* Sun Mar 09 2025 daviddavid <daviddavid> 4.3-9.mga10
+ Revision: 2162111
- rebuild for python 3.13
+ wally <wally>
- restore build flags patch removed in r2149069

* Sun Feb 16 2025 daviddavid <daviddavid> 4.3-8.mga10
+ Revision: 2149069
- no not override Mageia flags, thus fixing build

* Mon Dec 23 2024 daviddavid <daviddavid> 4.3-7.mga10
+ Revision: 2129322
- port to c99

* Wed Dec 27 2023 daviddavid <daviddavid> 4.3-6.mga10
+ Revision: 2022539
- rebuild for py3.12

* Mon Jan 30 2023 daviddavid <daviddavid> 4.3-5.mga9
+ Revision: 1937130
- backport some upstream fixes to fix segfault (mga#29939)
- switch to pyproject

* Sat Mar 19 2022 umeabot <umeabot> 4.3-4.mga9
+ Revision: 1799272
- Mageia 9 Mass Rebuild

* Tue Feb 22 2022 tv <tv> 4.3-3.mga9
+ Revision: 1782863
- Rebuild for python-3.10

* Mon Mar 22 2021 daviddavid <daviddavid> 4.3-2.mga9
+ Revision: 1707867
- rebuild for python 3.9

* Thu Nov 19 2020 daviddavid <daviddavid> 4.3-1.mga8
+ Revision: 1647641
- new version: 4.3

* Thu May 28 2020 daviddavid <daviddavid> 4.2-1.mga8
+ Revision: 1588345
- new version: 4.2

* Thu May 21 2020 daviddavid <daviddavid> 4.1-1.mga8
+ Revision: 1586562
- new version: 4.1

* Sun Feb 16 2020 umeabot <umeabot> 4.0.1-3.mga8
+ Revision: 1531316
- Mageia 8 Mass Rebuild

* Tue Sep 10 2019 wally <wally> 4.0.1-2.mga8
+ Revision: 1439422
- rebuild for python3.8

* Fri Apr 05 2019 daviddavid <daviddavid> 4.0.1-1.mga7
+ Revision: 1386067
- new version: 4.0.1
- port to Python 3

* Sun Sep 23 2018 umeabot <umeabot> 3.14.1-11.mga7
+ Revision: 1297946
- Mageia 7 Mass Rebuild

* Thu Feb 11 2016 umeabot <umeabot> 3.14.1-10.mga6
+ Revision: 954083
- Mageia 6 Mass Rebuild

* Sat Oct 17 2015 daviddavid <daviddavid> 3.14.1-9.mga6
+ Revision: 892427
- use new python2 macros (fix build failure)

* Wed Oct 15 2014 umeabot <umeabot> 3.14.1-8.mga5
+ Revision: 750704
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 3.14.1-7.mga5
+ Revision: 726355
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 3.14.1-6.mga5
+ Revision: 679695
- Mageia 5 Mass Rebuild

* Sat May 31 2014 pterjan <pterjan> 3.14.1-5.mga5
+ Revision: 628222
- Rebuild for new Python

* Tue Oct 22 2013 umeabot <umeabot> 3.14.1-4.mga4
+ Revision: 542540
- Mageia 4 Mass Rebuild

* Mon Oct 14 2013 pterjan <pterjan> 3.14.1-3.mga4
+ Revision: 497763
- Rebuild to add different pythonegg provides for python 2 and 3

* Thu Aug 08 2013 ofaurax <ofaurax> 3.14.1-2.mga4
+ Revision: 464657
- Add gcc as Requires (needed at runtime, see bug 9091)

* Sat Jul 27 2013 ofaurax <ofaurax> 3.14.1-1.mga4
+ Revision: 459132
- New version 3.14.1
  Use of tar.bz2

* Sun Feb 17 2013 wally <wally> 3.14-4.mga3
+ Revision: 398861
- fix source url
- use find_lang macro

* Sat Jan 12 2013 umeabot <umeabot> 3.14-3.mga3
+ Revision: 351948
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild
+ boklm <boklm>
- Update group: Graphics/Other -> Graphics/Utilities

* Sat Jan 05 2013 barjac <barjac> 3.14-2.mga3
+ Revision: 339228
- update group
- minor spec clean

* Sat Oct 01 2011 ofaurax <ofaurax> 3.14-1.mga2
+ Revision: 150719
- new version 3.14

* Mon Apr 18 2011 ofaurax <ofaurax> 3.13-2.mga1
+ Revision: 87481
- Patch to compile with libdl
- imported package gnofract4d


* Sun Nov 07 2010 Jani Välimaa <wally@mandriva.org> 3.13-2mdv2011.0
+ Revision: 594849
- rebuild for python 2.7
- fix install
- fix filelist (don't own /usr/share or /usr/lib{64,})
- fix file rights
- fix desktop file

* Sun Sep 19 2010 Olivier Faurax <ofaurax@mandriva.org> 3.13-1mdv2011.0
+ Revision: 579872
- New version 3.13 (oups)
- New version 3.13

* Mon Dec 28 2009 Olivier Faurax <ofaurax@mandriva.org> 3.12-1mdv2010.1
+ Revision: 483143
- import gnofract4d


